@@ -4,6 +4,7 @@ pub mod create;
 
 pub mod check;
 pub mod ensurepath;
+pub mod freeze;
 pub mod inject;
 pub mod install;
 pub mod list;
@@ -14,10 +15,14 @@ pub mod runpip;
 pub mod runpython;
 pub mod runuv;
 pub mod self_changelog;
+pub mod self_info;
+pub mod self_link;
 pub mod self_migrate;
 pub mod self_update;
+#[deprecated(since = "3.7.0")]
 pub mod self_version;
 pub mod setup;
+pub mod thaw;
 pub mod uninject;
 pub mod uninstall;
 pub mod uninstall_all;
